@@ -2,9 +2,10 @@
 #this repository contains the full copyright notices and license terms.
 'Address'
 from trytond.model import ModelView, ModelSQL, fields
+from trytond.pyson import Not, Bool, Eval, If, Greater
 
 STATES = {
-    'readonly': "active == False",
+    'readonly': Not(Bool(Eval('active'))),
 }
 
 
@@ -14,7 +15,8 @@ class Address(ModelSQL, ModelView):
     _description = __doc__
     party = fields.Many2One('party.party', 'Party', required=True,
             ondelete='CASCADE', select=1,  states={
-                'readonly': "(active == False) or (active_id > 0)",
+                'readonly': If(Not(Bool(Eval('active'))),
+                    True, Greater(Eval('active_id', 0), 0)),
             })
     name = fields.Char('Name', states=STATES)
     street = fields.Char('Street', states=STATES)
@@ -25,10 +27,12 @@ class Address(ModelSQL, ModelView):
     country = fields.Many2One('country.country', 'Country',
             states=STATES)
     subdivision = fields.Many2One("country.subdivision",
-            'Subdivision', domain=["('country', '=', country)"], states=STATES)
+            'Subdivision', domain=[('country', '=', Eval('country'))],
+            states=STATES)
     active = fields.Boolean('Active')
     sequence = fields.Integer("Sequence")
-    full_address = fields.Function('get_full_address', type='text')
+    full_address = fields.Function(fields.Text('Full Address'),
+            'get_full_address')
 
     def __init__(self):
         super(Address, self).__init__()
@@ -41,7 +45,7 @@ class Address(ModelSQL, ModelView):
     def default_active(self, cursor, user, context=None):
         return True
 
-    def get_full_address(self, cursor, user, ids, name, arg, context=None):
+    def get_full_address(self, cursor, user, ids, name, context=None):
         if not ids:
             return {}
         res = {}
@@ -77,7 +81,7 @@ class Address(ModelSQL, ModelView):
                     res[address.id] += address.country.name
         return res
 
-    def get_rec_name(self, cursor, user, ids, name, arg, context=None):
+    def get_rec_name(self, cursor, user, ids, name, context=None):
         if not ids:
             return {}
         res = {}
@@ -86,21 +90,15 @@ class Address(ModelSQL, ModelView):
                 address.party.rec_name, address.zip, address.city] if x)
         return res
 
-    def search_rec_name(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            ids = self.search(cursor, user, ['OR',
-                ('zip', args[i][1], args[i][2]),
-                ('city', args[i][1], args[i][2]),
-                ('name', args[i][1], args[i][2]),
-                ], context=context)
-            if ids:
-                args2.append(('id', 'in', ids))
-            else:
-                args2.append(('party', args[i][1], args[i][2]))
-            i += 1
-        return args2
+    def search_rec_name(self, cursor, user, name, clause, context=None):
+        ids = self.search(cursor, user, ['OR',
+            ('zip',) + clause[1:],
+            ('city',) + clause[1:],
+            ('name',) + clause[1:],
+            ], order=[], context=context)
+        if ids:
+            return [('id', 'in', ids)]
+        return [('party',) + clause[1:]]
 
     def write(self, cursor, user, ids, vals, context=None):
         if 'party' in vals:
