@@ -1,9 +1,10 @@
 #This file is part of Tryton.  The COPYRIGHT file at the top level of
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
+from trytond.pyson import Not, Bool, Eval, Equal, In
 
 STATES = {
-    'readonly': "active == False",
+    'readonly': Not(Bool(Eval('active'))),
 }
 
 _TYPES = [
@@ -34,36 +35,36 @@ class ContactMechanism(ModelSQL, ModelView):
             ondelete='CASCADE', states=STATES, select=1)
     active = fields.Boolean('Active', select=1)
     sequence = fields.Integer('Sequence')
-    email = fields.Function('get_value', fnct_inv='set_value', type='char',
-            string="E-Mail", states={
-                'invisible': "type != 'email'",
-                'required': "type == 'email'",
-                'readonly': "active == False",
-            }, on_change=['email'], depends=['value', 'type', 'active'])
-    website = fields.Function('get_value', fnct_inv='set_value', type='char',
-            string="Website", states={
-                'invisible': "type != 'website'",
-                'required': "type == 'website'",
-                'readonly': "active == False",
-            }, on_change=['website'], depends=['value', 'type', 'active'])
-    skype = fields.Function('get_value', fnct_inv='set_value', type='char',
-            string="Skype", states={
-                'invisible': "type != 'skype'",
-                'required': "type == 'skype'",
-                'readonly': "active == False",
-            }, on_change=['skype'], depends=['value', 'type', 'active'])
-    sip = fields.Function('get_value', fnct_inv='set_value', type='char',
-            string="SIP", states={
-                'invisible': "type != 'sip'",
-                'required': "type == 'sip'",
-                'readonly': "active == False",
-            }, on_change=['sip'], depends=['value', 'type', 'active'])
-    other_value = fields.Function('get_value', fnct_inv='set_value',
-            type='char', string='Value', states={
-                'invisible': "type in ('email', 'website', 'skype', 'sip')",
-                'required': "type not in ('email', 'website')",
-                'readonly': "active == False",
-            }, on_change=['other_value'], depends=['value', 'type', 'active'])
+    email = fields.Function(fields.Char('E-Mail', states={
+        'invisible': Not(Equal(Eval('type'), 'email')),
+        'required': Equal(Eval('type'), 'email'),
+        'readonly': Not(Bool(Eval('active'))),
+        }, on_change=['email'], depends=['value', 'type', 'active']),
+        'get_value', setter='set_value')
+    website = fields.Function(fields.Char('Website', states={
+        'invisible': Not(Equal(Eval('type'), 'website')),
+        'required': Equal(Eval('type'), 'website'),
+        'readonly': Not(Bool(Eval('active'))),
+        }, on_change=['website'], depends=['value', 'type', 'active']),
+        'get_value', setter='set_value')
+    skype = fields.Function(fields.Char('Skype',states={
+        'invisible': Not(Equal(Eval('type'), 'skype')),
+        'required': Equal(Eval('type'), 'skype'),
+        'readonly': Not(Bool(Eval('active'))),
+        }, on_change=['skype'], depends=['value', 'type', 'active']),
+        'get_value', setter='set_value')
+    sip = fields.Function(fields.Char('SIP', states={
+        'invisible': Not(Equal(Eval('type'), 'sip')),
+        'required': Equal(Eval('type'), 'sip'),
+        'readonly': Not(Bool(Eval('active'))),
+        }, on_change=['sip'], depends=['value', 'type', 'active']),
+        'get_value', setter='set_value')
+    other_value = fields.Function(fields.Char('Value', states={
+        'invisible': In(Eval('type'), ['email', 'website', 'skype', 'sip']),
+        'required': Not(In(Eval('type'), ['email', 'website'])),
+        'readonly': Not(Bool(Eval('active'))),
+        }, on_change=['other_value'], depends=['value', 'type', 'active']),
+        'get_value', setter='set_value')
 
     def __init__(self):
         super(ContactMechanism, self).__init__()
@@ -80,7 +81,7 @@ class ContactMechanism(ModelSQL, ModelView):
     def default_active(self, cursor, user, context=None):
         return True
 
-    def get_value(self, cursor, user, ids, names, arg, context=None):
+    def get_value(self, cursor, user, ids, names, context=None):
         res = {}
         for name in names:
             res[name] = {}
@@ -89,8 +90,8 @@ class ContactMechanism(ModelSQL, ModelView):
                 res[name][mechanism.id] = mechanism.value
         return res
 
-    def set_value(self, cursor, user, obj_id, name, value, arg, context=None):
-        self.write(cursor, user, obj_id, {
+    def set_value(self, cursor, user, ids, name, value, context=None):
+        self.write(cursor, user, ids, {
             'value': value,
             }, context=context)
 
@@ -104,27 +105,27 @@ class ContactMechanism(ModelSQL, ModelView):
             'other_value': value,
         }
 
-    def on_change_value(self, cursor, user, ids, vals, context=None):
+    def on_change_value(self, cursor, user, vals, context=None):
         return self._change_value(cursor, user, vals.get('value'),
                 context=context)
 
-    def on_change_website(self, cursor, user, ids, vals, context=None):
+    def on_change_website(self, cursor, user, vals, context=None):
         return self._change_value(cursor, user, vals.get('website'),
                 context=context)
 
-    def on_change_email(self, cursor, user, ids, vals, context=None):
+    def on_change_email(self, cursor, user, vals, context=None):
         return self._change_value(cursor, user, vals.get('email'),
                 context=context)
 
-    def on_change_skype(self, cursor, user, ids, vals, context=None):
+    def on_change_skype(self, cursor, user, vals, context=None):
         return self._change_value(cursor, user, vals.get('skype'),
                 context=context)
 
-    def on_change_sip(self, cursor, user, ids, vals, context=None):
+    def on_change_sip(self, cursor, user, vals, context=None):
         return self._change_value(cursor, user, vals.get('sip'),
                 context=context)
 
-    def on_change_other_value(self, cursor, user, ids, vals, context=None):
+    def on_change_other_value(self, cursor, user, vals, context=None):
         return self._change_value(cursor, user, vals.get('other_value'),
                 context=context)
 
