@@ -2,6 +2,7 @@
 #this repository contains the full copyright notices and license terms.
 from trytond.model import ModelView, ModelSQL, fields
 from trytond.wizard import Wizard
+from trytond.pyson import Not, Bool, Eval
 import logging
 
 HAS_VATNUMBER = False
@@ -16,7 +17,7 @@ except ImportError:
             'Unable to import vatnumber. VAT number validation disabled.')
 
 STATES = {
-    'readonly': "active == False",
+    'readonly': Not(Bool(Eval('active'))),
 }
 
 
@@ -33,12 +34,16 @@ class Party(ModelSQL, ModelView):
     code_length = fields.Integer('Code Length', select=1, readonly=True)
     lang = fields.Many2One("ir.lang", 'Language', states=STATES)
     vat_number = fields.Char('VAT Number', help="Value Added Tax number",
-            states=STATES)
+            states={
+                'readonly': Not(Bool(Eval('active'))),
+                'required': Bool(Eval('vat_country')),
+            })
     vat_country = fields.Selection(VAT_COUNTRIES, 'VAT Country', states=STATES,
         help="Setting VAT country will enable validation of the VAT number.",
         translate=False)
-    vat_code = fields.Function('get_vat_code', type='char', string="VAT Code",
-            fnct_search='search_vat_code')
+    vat_code = fields.Function(fields.Char('VAT Code',
+        on_change_with=['vat_number', 'vat_country']), 'get_vat_code',
+        searcher='search_vat_code')
     addresses = fields.One2Many('party.address', 'party',
            'Addresses', states=STATES)
     contact_mechanisms = fields.One2Many('party.contact_mechanism', 'party',
@@ -46,17 +51,12 @@ class Party(ModelSQL, ModelView):
     categories = fields.Many2Many('party.party-party.category',
             'party', 'category', 'Categories', states=STATES)
     active = fields.Boolean('Active', select=1)
-    full_name = fields.Function('get_full_name', type='char')
-    phone = fields.Function('get_mechanism', arg='phone', type='char',
-            string='Phone')
-    mobile = fields.Function('get_mechanism', arg='mobile', type='char',
-            string='Mobile')
-    fax = fields.Function('get_mechanism', arg='fax', type='char',
-            string='Fax')
-    email = fields.Function('get_mechanism', arg='email', type='char',
-            string='E-Mail')
-    website = fields.Function('get_mechanism', arg='website', type='char',
-            string='Website')
+    full_name = fields.Function(fields.Char('Full Name'), 'get_full_name')
+    phone = fields.Function(fields.Char('Phone'), 'get_mechanism')
+    mobile = fields.Function(fields.Char('Mobile'), 'get_mechanism')
+    fax = fields.Function(fields.Char('Fax'), 'get_mechanism')
+    email = fields.Function(fields.Char('E-Mail'), 'get_mechanism')
+    website = fields.Function(fields.Char('Website'), 'get_mechanism')
 
     def __init__(self):
         super(Party, self).__init__()
@@ -80,7 +80,10 @@ class Party(ModelSQL, ModelView):
             context = {}
         return context.get('categories', [])
 
-    def get_vat_code(self, cursor, user, ids, name, arg, context=None):
+    def on_change_with_vat_code(self, cursor, user, vals, context=None):
+        return (vals.get('vat_country') or '') + (vals.get('vat_number') or '')
+
+    def get_vat_code(self, cursor, user, ids, name, context=None):
         if not ids:
             return []
         res = {}
@@ -88,23 +91,20 @@ class Party(ModelSQL, ModelView):
             res[party.id] = (party.vat_country or '') + (party.vat_number or '')
         return res
 
-    def search_vat_code(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            value = args[i][2]
-            for country, _ in VAT_COUNTRIES:
-                if isinstance(value, basestring) \
-                        and country \
-                        and value.upper().startswith(country):
-                    args2.append(('vat_country', '=', country))
-                    value = value[len(country):]
-                    break
-            args2.append(('vat_number', args[i][1], value))
-            i += 1
-        return args2
+    def search_vat_code(self, cursor, user, name, clause, context=None):
+        res = []
+        value = clause[2]
+        for country, _ in VAT_COUNTRIES:
+            if isinstance(value, basestring) \
+                    and country \
+                    and value.upper().startswith(country):
+                res.append(('vat_country', '=', country))
+                value = value[len(country):]
+                break
+        res.append(('vat_number', clause[1], value))
+        return res
 
-    def get_full_name(self, cursor, user, ids, name, arg, context=None):
+    def get_full_name(self, cursor, user, ids, name, context=None):
         if not ids:
             return []
         res = {}
@@ -112,23 +112,28 @@ class Party(ModelSQL, ModelView):
             res[party.id] = party.name
         return res
 
-    def get_mechanism(self, cursor, user, ids, name, arg, context=None):
+    def get_mechanism(self, cursor, user, ids, name, context=None):
         if not ids:
             return []
         res = {}
         for party in self.browse(cursor, user, ids, context=context):
             res[party.id] = ''
             for mechanism in party.contact_mechanisms:
-                if mechanism.type == arg:
+                if mechanism.type == name:
                     res[party.id] = mechanism.value
                     break
         return res
 
     def create(self, cursor, user, values, context=None):
+        sequence_obj = self.pool.get('ir.sequence')
+        config_obj = self.pool.get('party.configuration')
+
         values = values.copy()
         if not values.get('code'):
-            values['code'] = self.pool.get('ir.sequence').get(
-                    cursor, user, 'party.party', context=context)
+            config = config_obj.browse(cursor, user, 1, context=context)
+            values['code'] = sequence_obj.get_id(cursor, user,
+                config.party_sequence.id, context=context)
+
         values['code_length'] = len(values['code'])
         return super(Party, self).create(cursor, user, values, context=context)
 
@@ -165,18 +170,14 @@ class Party(ModelSQL, ModelView):
             return new_ids[0]
         return new_ids
 
-    def search_rec_name(self, cursor, user, name, args, context=None):
-        args2 = []
-        i = 0
-        while i < len(args):
-            ids = self.search(cursor, user, [('code', args[i][1], args[i][2])],
-                    context=context)
-            if ids:
-                args2.append(('id', 'in', ids))
-            else:
-                args2.append(('name', args[i][1], args[i][2]))
-            i += 1
-        return args2
+    def search_rec_name(self, cursor, user, name, clause, context=None):
+        ids = self.search(cursor, user, [('code',) + clause[1:]],
+                order=[], context=context)
+        if ids:
+            ids += self.search(cursor, user, [('name',) + clause[1:]],
+                    order=[], context=context)
+            return [('id', 'in', ids)]
+        return [('name',) + clause[1:]]
 
     def address_get(self, cursor, user, party_id, type=None, context=None):
         """
@@ -208,7 +209,7 @@ class Party(ModelSQL, ModelView):
         for party in self.browse(cursor, user, ids):
             vat_number = party.vat_number
 
-            if not (vat_number and party.vat_country):
+            if not party.vat_country:
                 continue
 
             if not getattr(vatnumber, 'check_vat_' + \
@@ -254,11 +255,11 @@ class CheckVIESCheck(ModelView):
     _description = __doc__
     parties_succeed = fields.Many2Many('party.party', None, None,
             'Parties Succeed', readonly=True, states={
-                'invisible': "not bool(parties_succeed)",
+                'invisible': Not(Bool(Eval('parties_succeed'))),
                 })
     parties_failed = fields.Many2Many('party.party', None, None,
             'Parties Failed', readonly=True, states={
-                'invisible': "not bool(parties_failed)",
+                'invisible': Not(Bool(Eval('parties_failed'))),
                 })
 
 CheckVIESCheck()
